<?php
    /********************************************************************************** 
    *       Function:       read_response($socket) 
    *        Author:            Dan Wilson [dan--at--acucore.com] 
    *       Purpose:        Read the last response from the SMTP server and return the status and msg 
    *       Returns:        array(int, string) 
    *                            int - $status -- the first digit in the return code... 2 is good 
    *                            string - $resp_msg -- the full status message for displaying 
    *       Params:         $socket        -- socket/file handle of connection with SMTP server 
    *        Note:            This is used by the quick_dirty_email function only 
    **********************************************************************************/ 
     
    function read_response($socket) { 
        // This will contain the last status message from the SMTP server 
        $response    = fgets($socket, 1024); 
        $status     = substr($response, 0, 1); // Grab the first number of the status msg 
        $message     = substr($response, 0, strlen(trim($response))); 
        $resp_msg    = $message . "<br>"; 
        return array($status=>$resp_msg); 
    } 


    /********************************************************************************** 
    *       Function:       new_email($settings, $return_errors = false) 
    *        Author:            Dan Wilson [dan--at--acucore.com] 
    *       Purpose:        Send an email directly to an SMTP server (bypassing a call to sendmail) 
    *       Returns:        Success - true; Failure - Error Messages (if desired) 
    *       Params:         $settings    -- associated array of settings;  values include 
    *                            host        -- Host of SMTP         (default: localhost) 
    *                            port        -- SMPT Port             (default: 25) 
    *                            domain        -- Source domain        (default: $HTTP_HOST -- not always set) 
    *                            prior        -- Priority of msg        (default: 3 - Normal) 
    *                            crlf        -- 'Newline' for errmsg    (default: <br>) 
    *                            to            -- TO email address        (Can be in the form of 'Name <email@domain.com>') 
    *                            from        -- FROM email address    (Can be in the form of 'Name <email@domain.com>') 
    *                            cc            -- CC email address        (Can be in the form of 'Name <email@domain.com>') 
    *                            bcc            -- BCC email address    (Can be in the form of 'Name <email@domain.com>') 
    *                            reply        -- REPLY email address    (default: FROM email address) 
    *                            errors        -- ERROR email address    (default: REPLY email address) 
    * 
    *        Notes:             + This function relies on the function read_response... 
    *                        + When $return_errors is true, the return value must be cheched with an exact 
    *                          match operator (===)... you know... the triple equals thingy (see example below) 
    **********************************************************************************/ 
     
    function send_email($settings, $return_errors = true) { 
        // Set some constants 
        $STATUS_OK             = "2"; 
        $STATUS_DATA_OK     = "3"; 
        $CRLF                 = "\n"; 
     
        // Pull in any globals 
        global $error; 
         
        // Set the success or fail flag to fail 
        $send_success = false; 
        unset($error); 
     
        // Set some defaults 
        if (empty($settings[crlf]))     $settings[crlf]     = "<br>"; 
        if (empty($settings[host]))     $settings[host]     = "130.60.128.4"; 
        if (empty($settings[port]))     $settings[port]     = "25"; 
        if (empty($settings[domain]))     $settings[domain]     = $_SERVER['HTTP_HOST']; 
        if (empty($settings[prior]))     $settings[prior]     = 3; // Normal Priority 
         
        // Let's do some error checking 
        if (empty($settings[to]))         $error .= "TO address not specified" . $settings[crlf]; 
        if (empty($settings[from]))     $error .= "FROM address not specified" . $settings[crlf]; 
        if (empty($settings[msg]))         $error .= "MSG not speficied" . $settings[crlf]; 
        if (empty($settings[domain]))     $error .= "DOMAIN not specified" . $settings[crlf]; 
     
        if (empty($settings[reply]))    $settings[reply] = $settings[from]; 
        if (empty($settings[errors]))    $settings[errors] = $settings[reply]; 
     
        // Pull out the simple email if they are putting in 'name <email@domain.com>' 
        if (ereg("(([[:alnum:]]|\\-|\\.)+@([^[:space:]]*)([[:alnum:]-]))", $settings[to], $reg_array)) { 
           $simple_to = $reg_array[0]; 
       	} else { 
            $simple_to = $settings[to]; 
        } 
        if (ereg("(([[:alnum:]]|\\-|\\.)+@([^[:space:]]*)([[:alnum:]]|\\-|\\.))", $settings[from], $reg_array)) { 
            $simple_from = $reg_array[0]; 
        } else { 
            $simple_from = $settings[from]; 
        } 

        // If we already have errors, don't even attempt to open the socket 
        if (!empty($error)) {
            if ($return_errors) { 
                return $error; 
            } else { 
                return false; 
            } 
        } 
         
        if ($socket = fsockopen($settings[host], $settings[port])) { 
            list($status, $resp_msg) = each(read_response($socket)); 
            
            if ($status == $STATUS_OK) 
            { 
                fputs($socket, "HELO " . $settings[domain] . $CRLF); 
                list($status, $resp_msg) = each(read_response($socket)); 
                
                if ($status == $STATUS_OK) 
                { 
                    fputs($socket, "MAIL FROM:" . $simple_from . $CRLF); 
                    list($status, $resp_msg) = each(read_response($socket)); 
                    //echo "$resp_msg"; 
                    if ($status == $STATUS_OK) 
                    { 
                        fputs($socket, "RCPT TO: " . $simple_to . $CRLF); 
                        list($status, $resp_msg) = each(read_response($socket)); 
                      
                        if ($status == $STATUS_OK) 
                        {
                            fputs($socket, "DATA" . $CRLF); 
                            list($status, $resp_msg) = each(read_response($socket)); 
                            
                            if ($status == $STATUS_DATA_OK) 
                            { 
                                $buffer = "From: " . $settings[from] . $CRLF; 
                                $buffer .= "To: " . $settings[to] . $CRLF; 
                                if (!empty($settings[cc])) { 
                                    $buffer .= "CC: " . $settings[cc] . $CRLF; 
                                } 
                                if (!empty($settings[bcc])) { 
                                    $buffer .= "BCC: " . $settings[bcc] . $CRLF; 
                                } 
                                $buffer .= "Reply-To: " . $settings[reply] . $CRLF; 
                                $buffer .= "Errors-To: " . $settings[errors] . $CRLF; 
                                $buffer .= "Bounce-To: " . $settings[errors] . $CRLF; 
                                $buffer .= "X-Priority: " . $settings[prior] . $CRLF; 
                                $buffer .= "X-Mailer: QUICK-N-DIRTY Mailer w/PHP " . phpversion() . $CRLF; 
                                $buffer .= "Subject: " . $settings[subject] . $CRLF; 
                                $buffer .= $CRLF; 
                                $buffer .= $settings[msg]; 
                             
                                // echo nl2br($buffer); 
                                if (fputs($socket, $buffer . "$CRLF.$CRLF")) { 
                                    list($status, $resp_msg) = each(read_response($socket)); 
                                    if ($status == $STATUS_OK) { 
                                        $send_success = true; 
                                        fputs($socket, "QUIT" . $CRLF); 
                                    } 
                                } // Close fputs of buffer 
                            } // Close status of DATA command 
                        } // Close status of RCPT TO command 
                    } // Close status of MAIL FROM command 
                } // Close status of HELO command 
            } // Close status of SMPT welcome 
            fclose($socket); 
        } else { 
            $error .= "Unable to establish initial connection with " . $settings[host] . ":" . $settings[port] . $settings[crlf]; 
        } 
         
        if (!empty($resp_msg)) { 
            $error .= $resp_msg . $settings[crlf]; 
        } 
     
        if ($send_success) { 
            return true; 
        } else { 
            if ($return_errors && isset($error)) { 
                return $error; 
            } else { 
                return false; 
            } 
        } 
    }     

?>